==> kubernetes-model-discovery-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/EndpointConditionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class EndpointConditionsFluentImpl<A extends io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointConditionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointConditionsFluent<A>{
  public EndpointConditionsFluentImpl() {
  }
  public EndpointConditionsFluentImpl(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointConditions instance) {
    this.withReady(instance.getReady()); 
    this.withServing(instance.getServing()); 
    this.withTerminating(instance.getTerminating()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean ready;
  private java.lang.Boolean serving;
  private java.lang.Boolean terminating;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getReady() {
    return this.ready;
  }
  public A withReady(java.lang.Boolean ready) {
    this.ready=ready; return (A) this;
  }
  public java.lang.Boolean hasReady() {
    return this.ready != null;
  }
  public java.lang.Boolean getServing() {
    return this.serving;
  }
  public A withServing(java.lang.Boolean serving) {
    this.serving=serving; return (A) this;
  }
  public java.lang.Boolean hasServing() {
    return this.serving != null;
  }
  public java.lang.Boolean getTerminating() {
    return this.terminating;
  }
  public A withTerminating(java.lang.Boolean terminating) {
    this.terminating=terminating; return (A) this;
  }
  public java.lang.Boolean hasTerminating() {
    return this.terminating != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointConditionsFluentImpl that = (EndpointConditionsFluentImpl) o;
    if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
    if (serving != null ? !serving.equals(that.serving) :that.serving != null) return false;
    if (terminating != null ? !terminating.equals(that.terminating) :that.terminating != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  serving,  terminating,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-discovery-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/EndpointConditionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class EndpointConditionsFluentImpl<A extends io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointConditionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointConditionsFluent<A>{
  public EndpointConditionsFluentImpl() {
  }
  public EndpointConditionsFluentImpl(io.fabric8.kubernetes.api.model.discovery.v1beta1.EndpointConditions instance) {
    this.withReady(instance.getReady()); 
    this.withServing(instance.getServing()); 
    this.withTerminating(instance.getTerminating()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean ready;
  private java.lang.Boolean serving;
  private java.lang.Boolean terminating;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getReady() {
    return this.ready;
  }
  public A withReady(java.lang.Boolean ready) {
    this.ready=ready; return (A) this;
  }
  public java.lang.Boolean hasReady() {
    return this.ready != null;
  }
  public java.lang.Boolean getServing() {
    return this.serving;
  }
  public A withServing(java.lang.Boolean serving) {
    this.serving=serving; return (A) this;
  }
  public java.lang.Boolean hasServing() {
    return this.serving != null;
  }
  public java.lang.Boolean getTerminating() {
    return this.terminating;
  }
  public A withTerminating(java.lang.Boolean terminating) {
    this.terminating=terminating; return (A) this;
  }
  public java.lang.Boolean hasTerminating() {
    return this.terminating != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointConditionsFluentImpl that = (EndpointConditionsFluentImpl) o;
    if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
    if (serving != null ? !serving.equals(that.serving) :that.serving != null) return false;
    if (terminating != null ? !terminating.equals(that.terminating) :that.terminating != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  serving,  terminating,  additionalProperties,  super.hashCode());
  }
  
}
